WEATHER_CODE_MAP = {
    0:  ("Clear", None),
    1:  ("Mostly Clear", None),
    2:  ("Partly Cloudy", None),
    3:  ("Overcast", None),

    45: ("Fog", None),
    48: ("Icy Fog", None),

    51: ("Drizzle", "Light"),
    53: ("Drizzle", "Moderate"),
    55: ("Drizzle", "Heavy"),

    56: ("Freezing Drizzle", "Light"),
    57: ("Freezing Drizzle", "Heavy"),

    61: ("Rain", "Light"),
    63: ("Rain", "Moderate"),
    65: ("Rain", "Heavy"),

    66: ("Freezing Rain", "Light"),
    67: ("Freezing Rain", "Heavy"),

    71: ("Snow", "Light"),
    73: ("Snow", "Moderate"),
    75: ("Snow", "Heavy"),
    77: ("Snow Grains", None),

    80: ("Rain Showers", "Light"),
    81: ("Rain Showers", "Moderate"),
    82: ("Rain Showers", "Heavy"),

    85: ("Snow Showers", "Light"),
    86: ("Snow Showers", "Heavy"),

    95: ("Thunderstorm", None),
    96: ("Thunderstorm with Hail", "Light"),
    99: ("Thunderstorm with Hail", "Heavy"),
}

def get_weather_info(code: int):
    return WEATHER_CODE_MAP.get(code, ("unknown", None))




import requests
import configparser
from geopy.geocoders import Nominatim
import time

from config.weather_codes import get_weather_info

config = configparser.ConfigParser()
config.read('config/config.ini')

temperature_unit = config.get('CONFIG', 'temperature_unit')
windspeed_unit = config.get('CONFIG', 'windspeed_unit')
precipitation_unit = config.get('CONFIG', 'precipitation_unit')
timezone = config.get('CONFIG', 'timezone')

# Example location: Knoxville, TN
LAT = 35.9606
LON = -83.9207

def cords_to_city(LAT, LON):
    geolocator = Nominatim(user_agent="weather-display")
    time.sleep(1)
    location = geolocator.reverse(f"{LAT},{LON}")

    address = location.raw.get('address', {})

    city = address.get("city", "")
    state = address.get("state", "")
    country = address.get("country", "")

    return city, state, country

url = "https://api.open-meteo.com/v1/forecast"

params = {
    "latitude": LAT,
    "longitude": LON,
    "current_weather": True,
    "hourly": "precipitation,precipitation_probability,weathercode",
    "temperature_unit": {temperature_unit},
    "windspeed_unit": {windspeed_unit},
    "precipitation_unit": {precipitation_unit},
    "timezone": {timezone}
}

response = requests.get(url, params=params, timeout=10)
response.raise_for_status()

data = response.json()

current = data["current_weather"]

current_temp = current["temperature"]
current_wind_speed = current["windspeed"]
current_wind_dir = current["winddirection"]

hourly = data["hourly"]

precip_amount = hourly["precipitation"][0]
precip_probability = hourly["precipitation_probability"][0]
weather_code = hourly["weathercode"][0]
precip_type, intensity = get_weather_info(weather_code)

def display_data():
    print(f"Location: {city}, {state} {country}")

    if  temperature_unit == "fahrenheit":
        print(f"Temperature: {current_temp} °F")
    elif temperature_unit == "celcius":
        print(f"Temperature: {current_temp} °C")

    print(f"Wind: {current_wind_speed} {windspeed_unit} @ {current_wind_dir}°")

    if intensity is not None:
        print(f"Preciptiation: {intensity} {precip_type}")
    else:
        print("Preciptiation:", precip_type)

    print(f"Chance: {precip_probability}%")

    if precipitation_unit == 'inch':
        print(f"Accumulation: {precip_amount} in")
    elif precipitation_unit == 'centimeter':
        print(f"Accumulation: {precip_amount} cm")

cords_to_city(LAT, LON)
city, state, country = cords_to_city(LAT, LON)
display_data()



import os
import sys
import configparser
import pytermgui as ptg

from config.weather_codes import get_weather_info

print ("Loading data...")

config = configparser.ConfigParser()
config.read('config/config.ini')

temperature_unit = config.get('CONFIG', 'temperature_unit')
windspeed_unit = config.get('CONFIG', 'windspeed_unit')
precipitation_unit = config.get('CONFIG', 'precipitation_unit')
timezone = config.get('CONFIG', 'timezone')

from backend import current_temp, current_wind_speed, current_wind_dir, precip_type, precip_probability, precip_amount, intensity, city, state, country

def quit_func(button):
    quit()

def reload_data(manager):
    manager.stop()
    if os.name == "nt":
        _ = os.system("cls")
    else:
        _ = os.system("clear")
    print("Loading data...")
    python = sys.executable
    os.execv(python, [python] + sys.argv)

with ptg.WindowManager() as manager:
    manager.layout.add_slot("body")

    if temperature_unit == "fahrenheit":
        temp_display_unit = "°F"
    elif temperature_unit == "celcius":
        temp_display_unit = "°C"

    if intensity is not None:
        precip_display = f"Precipitation: {intensity} {precip_type}"
    else:
        precip_display = f"Precipitation: {precip_type}"
    # Create two columns using Splitter
    left_column = ptg.Container(
        ptg.Label(f"Location: {city}, {state} {country}"),
        ptg.Label(f"Tempurature: {current_temp} {temp_display_unit}", wrap=False),
        ptg.Label(f"Wind: {current_wind_speed} {windspeed_unit} @ {current_wind_dir}°", wrap=False),
    )

    if precipitation_unit == 'inch':
        precip_unit_display = "in"
    elif precipitation_unit == "centimeters":
        precip_unit_display = "cm"

    right_column = ptg.Container(
        ptg.Label(precip_display),
        ptg.Label(f"Chance: %{precip_probability}", wrap=False),
        ptg.Label(f"Accumulation: {precip_amount} {precip_unit_display}")
    )

    # Splitter will create two columns
    splitter = ptg.Splitter(left_column, right_column)

    quit_button = ptg.KeyboardButton("Quit", onclick=quit_func, bound="Q"),
    reload_button = ptg.KeyboardButton("Reload Data", onclick=lambda *_: reload_data(manager), bound="R"),
    button_split = ptg.Splitter(quit_button, reload_button)

    window = (
        ptg.Window(
            splitter,
            button_split,
            width=0,
        )
        .set_title("weather-display")
    )

    manager.add(window)

